import React from 'react';
import { motion } from 'framer-motion';

const SimpleLoader = ({ size = "35px" }) => {
    return (React.createElement(React.Fragment, null,
        React.createElement("div", { style: { padding: "5px", width: 'auto', height: 'auto' } }),
        React.createElement(motion.div, { style: { height: size, width: size, borderRadius: "100%", backgroundColor: "transparent", border: "7px solid rgba(0, 0, 0, 0.193)", borderTop: "7px solid #3498db" }, initial: {
                scale: 1,
                x: 0,
            }, animate: {
                scale: 1,
                x: 0,
                rotate: 360,
            }, transition: {
                duration: 0.8,
                ease: "easeInOut",
                repeat: Infinity,
                repeatDelay: 0
            } })));
};

const PulseSphere = ({ size = "30px", color = "#1c64f2", fillcolor = "transparent" }) => {
    return (React.createElement(React.Fragment, null,
        React.createElement(motion.div, { style: {
                padding: "5px",
                height: size,
                width: size,
                border: `3px solid ${color}`,
                borderRadius: "100%",
                backgroundColor: `${fillcolor}`
            }, 
            // className="pusle-sphere"
            initial: { scale: 0.5, x: 0 }, animate: {
                scale: [0.5, 1, 0.5],
            }, transition: {
                duration: 2,
                ease: "easeInOut",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0
            } })));
};

const WavyBars = ({ color = "#1c64f2" }) => {
    return (React.createElement("div", { style: { padding: "5px", width: 'auto', height: 'auto', display: "flex", justifyContent: "center", alignItems: "center" } },
        React.createElement(motion.div, { style: { height: "5px", margin: "2px", width: "5px", backgroundColor: color, borderRadius: '20px 20px  20px 20px' }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                height: ["5px", "30px", "5px"],
            }, transition: {
                duration: .8,
                ease: "easeInOut",
                repeat: Infinity,
                repeatDelay: 0,
            } }),
        React.createElement(motion.div, { style: { height: "5px", margin: "2px", width: "5px", backgroundColor: color, borderRadius: '20px 20px  20px 20px' }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                height: ["5px", "30px", "5px"],
            }, transition: {
                duration: .9,
                ease: "easeInOut",
                repeat: Infinity,
                repeatDelay: 0
            } }),
        React.createElement(motion.div, { style: { height: "5px", margin: "2px", width: "5px", backgroundColor: color, borderRadius: '20px 20px  20px 20px' }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                height: ["5px", "30px", "5px"],
            }, transition: {
                duration: 1,
                ease: "easeInOut",
                repeat: Infinity,
                repeatDelay: 0
            } })));
};

const WavyPulses = ({ color = "#1c64f2", size = "5px" }) => {
    return (React.createElement("div", { style: { padding: "5px", width: 'auto', height: 'auto', display: "flex", justifyContent: "center", alignItems: "center" } },
        React.createElement(motion.div, { style: { height: size, margin: "3px", width: size, backgroundColor: color, borderRadius: '20px 20px  20px 20px' }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                y: [0, -10, 0]
            }, transition: {
                duration: .8,
                ease: "easeInOut",
                times: [0, 0.5, 1],
                repeat: Infinity,
                repeatDelay: 0,
            } }),
        React.createElement(motion.div, { style: { height: size, margin: "3px", width: size, backgroundColor: color, borderRadius: '20px 20px  20px 20px' }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                y: [0, -10, 0]
            }, transition: {
                duration: 0.8,
                ease: "easeInOut",
                times: [0, 0.7, 1],
                repeat: Infinity,
                repeatDelay: 0,
            } }),
        React.createElement(motion.div, { style: { height: size, margin: "3px", width: size, backgroundColor: color, borderRadius: '20px 20px  20px 20px' }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                y: [0, -9, 0]
            }, transition: {
                duration: .8,
                ease: "easeInOut",
                times: [0, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
            } })));
};

const RotatingRing = ({ size = "25px", color = "#1c64f2", lineWidth = "2px", speed = .7 }) => {
    return (React.createElement("div", { style: { padding: "5px", width: "auto", height: "auto" } },
        React.createElement(motion.div, { style: { height: size, width: size, background: "transparent", border: `${lineWidth} solid ${color}`, borderTop: `${lineWidth} solid transparent`, borderRadius: "100%" }, initial: {
                scale: 1,
                x: 0,
                opacity: 1
            }, animate: {
                scale: 1,
                rotate: 360
            }, transition: {
                duration: speed,
                ease: "linear",
                repeat: Infinity,
                repeatDelay: 0,
            } })));
};

const ScalingPulses = ({ size = "10px", color = "#1c64f2", speed = .7 }) => {
    return (React.createElement("div", { style: { padding: "5px", width: "auto", height: "auto", display: "flex", justifyContent: "center", alignItems: "center" } },
        React.createElement(motion.div, { style: { height: size, width: size, background: "#808080", borderRadius: "100%", margin: "4px" }, initial: {
                scale: 1,
                x: 0,
                opacity: 1,
            }, animate: {
                scale: [1, 1.2, 1, 1, 1],
                backgroundColor: ["#808080", color, "#808080", "#808080", "#808080"],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
            } }),
        React.createElement(motion.div, { style: { height: size, width: size, background: "gray", borderRadius: "100%" }, initial: {
                scale: 1,
                x: 0,
                opacity: 1,
            }, animate: {
                scale: [1, 1, 1.2, 1, 1],
                backgroundColor: ["#808080", "#808080", color, "#808080", "#808080"],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
            } }),
        React.createElement(motion.div, { style: { height: size, width: size, background: "gray", borderRadius: "100%", margin: "4px" }, initial: {
                scale: 1,
                x: 0,
                opacity: 1,
            }, animate: {
                scale: [1, 1, 1, 1.2, 1],
                backgroundColor: ["#808080", "#808080", "#808080", color, "#808080"],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
            } })));
};

const ButterflyWave = ({ width = "5px", color = "#1c64f2", speed = .6 }) => {
    return (React.createElement("div", { style: { padding: "5px", display: "flex", justifyContent: "center", alignItems: "center", width: "auto", height: "auto" } },
        React.createElement(motion.div, { style: { height: "35px", width: width, borderRadius: '3px', background: color, margin: "3px" }, initial: {
                opacity: 1,
            }, animate: {
                scale: [1.2, 1, 1, 1, 1],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
                repeatType: "reverse",
            } }),
        React.createElement(motion.div, { style: { height: "25px", width: width, borderRadius: '3px', background: color, margin: "3px" }, initial: {
                opacity: 1,
            }, animate: {
                scale: [1, 1.2, 1, 1, 1],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
                repeatType: "reverse",
            } }),
        React.createElement(motion.div, { style: { height: "12px", width: width, borderRadius: '3px', background: color, margin: "3px" }, initial: {
                x: 0,
                opacity: 1,
            }, animate: {
                scale: [1, 1, 1.2, 1, 1],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
                repeatType: "reverse",
            } }),
        React.createElement(motion.div, { style: { height: "25px", width: width, borderRadius: '3px', background: color, margin: "3px" }, initial: {
                opacity: 1,
            }, animate: {
                scale: [1, 1, 1, 1.2, 1],
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
                repeatType: "reverse",
            } }),
        React.createElement(motion.div, { style: { height: "35px", width: width, borderRadius: '3px', background: color, margin: "3px" }, initial: {
                opacity: 1,
            }, animate: {
                scale: [1, 1, 1, 1, 1.2],
                borderRadius: '3px'
            }, transition: {
                duration: speed,
                ease: "linear",
                times: [0, 0.2, 0.5, 0.8, 1],
                repeat: Infinity,
                repeatDelay: 0,
                repeatType: "reverse",
            } })));
};

export { ButterflyWave, PulseSphere, RotatingRing, ScalingPulses, SimpleLoader, WavyBars, WavyPulses };
